._lib_extender__otherClass { background: red; }
._lib_extender__andAgain { font-size: 2em; }
._lib_extender__aThirdClass { color: red; }
._lib_extender__exportName { color: green; }
:export {
  otherClass: _lib_extender__otherClass;
  andAgain: _lib_extender__andAgain;
  aThirdClass: _lib_extender__aThirdClass;
  exportName: _lib_extender__exportName _lib_extender__otherClass _lib_extender__andAgain _lib_extender__aThirdClass; }