._input__exportName {
  color: green;
}

._input__exportName:hover {
  color: red;
}

._input__\:\:\:\: {
  color: rebeccapurple;
}

._input__\31 a2b3c {
  color: gainsboro;
}

._input__\32 {
  color: aqua;
}

._input__𝌆 {
  color: fuchsia;
}

._input__u-m\00002b {
  color: maroon;
}

#_input__u-m\+ {
  color: navy;
}

@media (max-width: 520px) {
  /* selector doubled to increase specificity */
  ._input__exportName._input__exportName {
    color: darkgreen;
  }

  ._input__newExport {
    color: blue;
  }
}

:export {
  2: _input__2;
  exportName: _input__exportName;
  ::::: _input__::::;
  1a2b3c: _input__1a2b3c;
  𝌆: _input__𝌆;
  u-m+: _input__u-m+;
  newExport: _input__newExport;
}
