._lib_extender__otherClass { background: red; } ._lib_extender__exportName { color: green; } :export {
  otherClass: _lib_extender__otherClass;
  exportName: _lib_extender__exportName _lib_extender__otherClass; }