@keyframes _input__fade-in {
  from {
    opacity: 0;
  }
  100% {
    opacity: 1;
  }
}

@keyframes fade {
  from {
    opacity: 0.5;
  }
}

._input__fadeIn {
  animation-name: _input__fade-in;
}

._input__fadeIn {
  animation: 2s _input__fade-in;
}

._input__fadeIn {
  animation: _input__fade-in 2s;
}

:export {
  fadeIn: _input__fadeIn;
  fade-in: _input__fade-in;
}
