:local(.otherClass) { background: red; }
:local(.andAgain) { font-size: 2em; }
:local(.aThirdClass) { color: red; }
:local(.exportName) { compose-with: otherClass andAgain; compose-with: aThirdClass; color: green; }
