.exportName {
  color: green;
}

.exportName:hover {
  color: red;
}

@media screen {
  body {
    background: red;
  }
}

._input__testLocal {
  color: blue;
}

:export {
  exportName: exportName;
  testLocal: _input__testLocal;
}
