@keyframes :local(fade-in) {
  from {
    opacity: 0;
  }
  100% {
    opacity: 1;
  }
}

@keyframes fade {
  from {
    opacity: 0.5;
  }
}

:local(.fadeIn) {
  animation-name: _colon_local(fade-in);
}

:local(.fadeIn) {
  animation: 2s _colon_local(fade-in);
}

:local(.fadeIn) {
  animation: _colon_local(fade-in) 2s;
}