.otherClass { background: red; }
.andAgain { font-size: 2em; }
.aThirdClass { color: red; }
._lib_extender__exportName { color: green; }
:export {
  exportName: _lib_extender__exportName otherClass andAgain aThirdClass; }
