:local(.exportName) {
  color: green;
}

:local(.exportName):hover {
  color: red;
}

:local(.\:\:\:\:) {
  color: rebeccapurple;
}

:local(.\31 a2b3c) {
  color: gainsboro;
}

:local(.\32) {
  color: aqua;
}

:local(.𝌆) {
  color: fuchsia;
}

:local(.u-m\00002b) {
  color: maroon;
}

:local(#u-m\+) {
  color: navy;
}

@media (max-width: 520px) {
  /* selector doubled to increase specificity */
  :local(.exportName):local(.exportName) {
    color: darkgreen;
  }

  :local(.newExport) {
    color: blue;
  }
}
