@keyframes _input__fade-in {
  from {
    opacity: 0;
  }
}

@-webkit-keyframes _input__fade-out {
  to {
    opacity: 0;
  }
}

._input__fadeIn {
  animation: _input__fade-in 5s,
    _input__fade-out 1s :local(wrong);
  content: _input__fade-in, wrong, "difficult, :local(wrong)" :local(wrong);
}

:export {
  fadeIn: _input__fadeIn;
  fade-in: _input__fade-in;
  fade-out: _input__fade-out;
}
